==> haskell-quickcheck-assertions-0.3.0-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-assertions
version: 0.3.0
id: quickcheck-assertions-0.3.0-EXZRrPduv95KFJQz8RrRF
key: quickcheck-assertions-0.3.0-EXZRrPduv95KFJQz8RrRF
license: LGPL-3
maintainer: s9gf4ult@gmail.com
homepage: https://github.com/s9gf4ult/quickcheck-assertions
synopsis: HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit
category: Testing
author: Aleksey Uymanov
exposed: True
indefinite: False
exposed-modules:
    Test.QuickCheck.Assertions
abi: 17e02262820c1b4e5ed64c1a5b06829f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/quickcheck-assertions-0.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/quickcheck-assertions-0.3.0
hs-libraries: HSquickcheck-assertions-0.3.0-EXZRrPduv95KFJQz8RrRF
depends:
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
    ieee754-0.8.0-B9FdsnFZjDO5G55ttUSqU0
    pretty-show-1.6.16-4yL3QMm4omX5sydQq6eqFv
abi-depends: QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             ieee754-0.8.0-B9FdsnFZjDO5G55ttUSqU0=b8bb49b8cfa609e010a6613d88ba1169
             pretty-show-1.6.16-4yL3QMm4omX5sydQq6eqFv=a68af35cb8ebe4069d7cae43e78dc845
haddock-interfaces: /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-assertions-0.3.0-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-assertions
version: 0.3.0
id: quickcheck-assertions-0.3.0-9ThTUgSvNDGINg0T3Qbpqd
key: quickcheck-assertions-0.3.0-9ThTUgSvNDGINg0T3Qbpqd
license: LGPL-3
maintainer: s9gf4ult@gmail.com
homepage: https://github.com/s9gf4ult/quickcheck-assertions
synopsis: HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit
category: Testing
author: Aleksey Uymanov
exposed: True
indefinite: False
exposed-modules:
    Test.QuickCheck.Assertions
abi: ec51d2cbff159b69c5e8652b2829565f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/quickcheck-assertions-0.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/quickcheck-assertions-0.3.0
hs-libraries: HSquickcheck-assertions-0.3.0-9ThTUgSvNDGINg0T3Qbpqd
depends:
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
    ieee754-0.8.0-B9FdsnFZjDO5G55ttUSqU0
    pretty-show-1.6.16-4yL3QMm4omX5sydQq6eqFv
abi-depends: QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             ieee754-0.8.0-B9FdsnFZjDO5G55ttUSqU0=b8bb49b8cfa609e010a6613d88ba1169
             pretty-show-1.6.16-4yL3QMm4omX5sydQq6eqFv=a68af35cb8ebe4069d7cae43e78dc845
haddock-interfaces: /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
